@@ -65,6 +65,7 @@ from .type_defs import (
     EC2TagFilterTypeDef,
     EC2TagSetTypeDef,
     ECSServiceTypeDef,
+    EmptyResponseMetadataTypeDef,
     GetApplicationOutputTypeDef,
     GetApplicationRevisionOutputTypeDef,
     GetDeploymentConfigOutputTypeDef,
@@ -250,8 +251,8 @@ class CodeDeployClient(BaseClient):
         """
 
     def add_tags_to_on_premises_instances(
-        self, *, tags: Sequence["TagTypeDef"], instanceNames: Sequence[str]
-    ) -> None:
+        self, *, tags: Sequence[TagTypeDef], instanceNames: Sequence[str]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Adds tags to on-premises instances.
 
@@ -260,7 +261,7 @@ class CodeDeployClient(BaseClient):
         """
 
     def batch_get_application_revisions(
-        self, *, applicationName: str, revisions: Sequence["RevisionLocationTypeDef"]
+        self, *, applicationName: str, revisions: Sequence[RevisionLocationTypeDef]
     ) -> BatchGetApplicationRevisionsOutputTypeDef:
         """
         Gets information about one or more application revisions.
@@ -339,7 +340,7 @@ class CodeDeployClient(BaseClient):
 
     def continue_deployment(
         self, *, deploymentId: str = ..., deploymentWaitType: DeploymentWaitTypeType = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         For a blue/green deployment, starts the process of rerouting traffic from
         instances in the original environment to instances in the replacement
@@ -354,7 +355,7 @@ class CodeDeployClient(BaseClient):
         *,
         applicationName: str,
         computePlatform: ComputePlatformType = ...,
-        tags: Sequence["TagTypeDef"] = ...
+        tags: Sequence[TagTypeDef] = ...
     ) -> CreateApplicationOutputTypeDef:
         """
         Creates an application.
@@ -368,12 +369,12 @@ class CodeDeployClient(BaseClient):
         *,
         applicationName: str,
         deploymentGroupName: str = ...,
-        revision: "RevisionLocationTypeDef" = ...,
+        revision: RevisionLocationTypeDef = ...,
         deploymentConfigName: str = ...,
         description: str = ...,
         ignoreApplicationStopFailures: bool = ...,
-        targetInstances: "TargetInstancesTypeDef" = ...,
-        autoRollbackConfiguration: "AutoRollbackConfigurationTypeDef" = ...,
+        targetInstances: TargetInstancesTypeDef = ...,
+        autoRollbackConfiguration: AutoRollbackConfigurationTypeDef = ...,
         updateOutdatedInstancesOnly: bool = ...,
         fileExistsBehavior: FileExistsBehaviorType = ...
     ) -> CreateDeploymentOutputTypeDef:
@@ -388,8 +389,8 @@ class CodeDeployClient(BaseClient):
         self,
         *,
         deploymentConfigName: str,
-        minimumHealthyHosts: "MinimumHealthyHostsTypeDef" = ...,
-        trafficRoutingConfig: "TrafficRoutingConfigTypeDef" = ...,
+        minimumHealthyHosts: MinimumHealthyHostsTypeDef = ...,
+        trafficRoutingConfig: TrafficRoutingConfigTypeDef = ...,
         computePlatform: ComputePlatformType = ...
     ) -> CreateDeploymentConfigOutputTypeDef:
         """
@@ -406,20 +407,20 @@ class CodeDeployClient(BaseClient):
         deploymentGroupName: str,
         serviceRoleArn: str,
         deploymentConfigName: str = ...,
-        ec2TagFilters: Sequence["EC2TagFilterTypeDef"] = ...,
-        onPremisesInstanceTagFilters: Sequence["TagFilterTypeDef"] = ...,
+        ec2TagFilters: Sequence[EC2TagFilterTypeDef] = ...,
+        onPremisesInstanceTagFilters: Sequence[TagFilterTypeDef] = ...,
         autoScalingGroups: Sequence[str] = ...,
-        triggerConfigurations: Sequence["TriggerConfigTypeDef"] = ...,
-        alarmConfiguration: "AlarmConfigurationTypeDef" = ...,
-        autoRollbackConfiguration: "AutoRollbackConfigurationTypeDef" = ...,
+        triggerConfigurations: Sequence[TriggerConfigTypeDef] = ...,
+        alarmConfiguration: AlarmConfigurationTypeDef = ...,
+        autoRollbackConfiguration: AutoRollbackConfigurationTypeDef = ...,
         outdatedInstancesStrategy: OutdatedInstancesStrategyType = ...,
-        deploymentStyle: "DeploymentStyleTypeDef" = ...,
-        blueGreenDeploymentConfiguration: "BlueGreenDeploymentConfigurationTypeDef" = ...,
-        loadBalancerInfo: "LoadBalancerInfoTypeDef" = ...,
-        ec2TagSet: "EC2TagSetTypeDef" = ...,
-        ecsServices: Sequence["ECSServiceTypeDef"] = ...,
-        onPremisesTagSet: "OnPremisesTagSetTypeDef" = ...,
-        tags: Sequence["TagTypeDef"] = ...
+        deploymentStyle: DeploymentStyleTypeDef = ...,
+        blueGreenDeploymentConfiguration: BlueGreenDeploymentConfigurationTypeDef = ...,
+        loadBalancerInfo: LoadBalancerInfoTypeDef = ...,
+        ec2TagSet: EC2TagSetTypeDef = ...,
+        ecsServices: Sequence[ECSServiceTypeDef] = ...,
+        onPremisesTagSet: OnPremisesTagSetTypeDef = ...,
+        tags: Sequence[TagTypeDef] = ...
     ) -> CreateDeploymentGroupOutputTypeDef:
         """
         Creates a deployment group to which application revisions are deployed.
@@ -428,7 +429,7 @@ class CodeDeployClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/client/#create_deployment_group)
         """
 
-    def delete_application(self, *, applicationName: str) -> None:
+    def delete_application(self, *, applicationName: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes an application.
 
@@ -436,7 +437,9 @@ class CodeDeployClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/client/#delete_application)
         """
 
-    def delete_deployment_config(self, *, deploymentConfigName: str) -> None:
+    def delete_deployment_config(
+        self, *, deploymentConfigName: str
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes a deployment configuration.
 
@@ -472,7 +475,7 @@ class CodeDeployClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/client/#delete_resources_by_external_id)
         """
 
-    def deregister_on_premises_instance(self, *, instanceName: str) -> None:
+    def deregister_on_premises_instance(self, *, instanceName: str) -> EmptyResponseMetadataTypeDef:
         """
         Deregisters an on-premises instance.
 
@@ -503,7 +506,7 @@ class CodeDeployClient(BaseClient):
         """
 
     def get_application_revision(
-        self, *, applicationName: str, revision: "RevisionLocationTypeDef"
+        self, *, applicationName: str, revision: RevisionLocationTypeDef
     ) -> GetApplicationRevisionOutputTypeDef:
         """
         Gets information about an application revision.
@@ -651,7 +654,7 @@ class CodeDeployClient(BaseClient):
         deploymentGroupName: str = ...,
         externalId: str = ...,
         includeOnlyStatuses: Sequence[DeploymentStatusType] = ...,
-        createTimeRange: "TimeRangeTypeDef" = ...,
+        createTimeRange: TimeRangeTypeDef = ...,
         nextToken: str = ...
     ) -> ListDeploymentsOutputTypeDef:
         """
@@ -676,7 +679,7 @@ class CodeDeployClient(BaseClient):
         self,
         *,
         registrationStatus: RegistrationStatusType = ...,
-        tagFilters: Sequence["TagFilterTypeDef"] = ...,
+        tagFilters: Sequence[TagFilterTypeDef] = ...,
         nextToken: str = ...
     ) -> ListOnPremisesInstancesOutputTypeDef:
         """
@@ -712,8 +715,8 @@ class CodeDeployClient(BaseClient):
         """
 
     def register_application_revision(
-        self, *, applicationName: str, revision: "RevisionLocationTypeDef", description: str = ...
-    ) -> None:
+        self, *, applicationName: str, revision: RevisionLocationTypeDef, description: str = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Registers with AWS CodeDeploy a revision for the specified application.
 
@@ -723,7 +726,7 @@ class CodeDeployClient(BaseClient):
 
     def register_on_premises_instance(
         self, *, instanceName: str, iamSessionArn: str = ..., iamUserArn: str = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Registers an on-premises instance.
 
@@ -732,8 +735,8 @@ class CodeDeployClient(BaseClient):
         """
 
     def remove_tags_from_on_premises_instances(
-        self, *, tags: Sequence["TagTypeDef"], instanceNames: Sequence[str]
-    ) -> None:
+        self, *, tags: Sequence[TagTypeDef], instanceNames: Sequence[str]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Removes one or more tags from one or more on-premises instances.
 
@@ -741,7 +744,9 @@ class CodeDeployClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/client/#remove_tags_from_on_premises_instances)
         """
 
-    def skip_wait_time_for_instance_termination(self, *, deploymentId: str = ...) -> None:
+    def skip_wait_time_for_instance_termination(
+        self, *, deploymentId: str = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         In a blue/green deployment, overrides any specified wait time and starts
         terminating instances immediately after the traffic routing is complete.
@@ -760,7 +765,7 @@ class CodeDeployClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/client/#stop_deployment)
         """
 
-    def tag_resource(self, *, ResourceArn: str, Tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceArn: str, Tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
         """
         Associates the list of tags in the input `Tags` parameter with the resource
         identified by the `ResourceArn` input parameter.
@@ -779,7 +784,7 @@ class CodeDeployClient(BaseClient):
 
     def update_application(
         self, *, applicationName: str = ..., newApplicationName: str = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Changes the name of an application.
 
@@ -794,20 +799,20 @@ class CodeDeployClient(BaseClient):
         currentDeploymentGroupName: str,
         newDeploymentGroupName: str = ...,
         deploymentConfigName: str = ...,
-        ec2TagFilters: Sequence["EC2TagFilterTypeDef"] = ...,
-        onPremisesInstanceTagFilters: Sequence["TagFilterTypeDef"] = ...,
+        ec2TagFilters: Sequence[EC2TagFilterTypeDef] = ...,
+        onPremisesInstanceTagFilters: Sequence[TagFilterTypeDef] = ...,
         autoScalingGroups: Sequence[str] = ...,
         serviceRoleArn: str = ...,
-        triggerConfigurations: Sequence["TriggerConfigTypeDef"] = ...,
-        alarmConfiguration: "AlarmConfigurationTypeDef" = ...,
-        autoRollbackConfiguration: "AutoRollbackConfigurationTypeDef" = ...,
+        triggerConfigurations: Sequence[TriggerConfigTypeDef] = ...,
+        alarmConfiguration: AlarmConfigurationTypeDef = ...,
+        autoRollbackConfiguration: AutoRollbackConfigurationTypeDef = ...,
         outdatedInstancesStrategy: OutdatedInstancesStrategyType = ...,
-        deploymentStyle: "DeploymentStyleTypeDef" = ...,
-        blueGreenDeploymentConfiguration: "BlueGreenDeploymentConfigurationTypeDef" = ...,
-        loadBalancerInfo: "LoadBalancerInfoTypeDef" = ...,
-        ec2TagSet: "EC2TagSetTypeDef" = ...,
-        ecsServices: Sequence["ECSServiceTypeDef"] = ...,
-        onPremisesTagSet: "OnPremisesTagSetTypeDef" = ...
+        deploymentStyle: DeploymentStyleTypeDef = ...,
+        blueGreenDeploymentConfiguration: BlueGreenDeploymentConfigurationTypeDef = ...,
+        loadBalancerInfo: LoadBalancerInfoTypeDef = ...,
+        ec2TagSet: EC2TagSetTypeDef = ...,
+        ecsServices: Sequence[ECSServiceTypeDef] = ...,
+        onPremisesTagSet: OnPremisesTagSetTypeDef = ...
     ) -> UpdateDeploymentGroupOutputTypeDef:
         """
         Changes information about a deployment group.
